Struct Cfgr2
#[repr(transparent)]pub struct Cfgr2(pub u32);Expand description
Configuration register 2
Tuple Fields
0: u32Implementations
impl Cfgr2
impl Cfgr2
pub const fn ovss(&self) -> u8
pub const fn ovss(&self) -> u8
Oversampling shift (number of bits to right-shift the accumulated result)
pub const fn set_ovss(&mut self, val: u8)
pub const fn set_ovss(&mut self, val: u8)
Oversampling shift (number of bits to right-shift the accumulated result)
pub const fn tovs(&self) -> bool
pub const fn tovs(&self) -> bool
Triggered oversampling (0: all oversampled conversions are run after a single trigger, 1: each oversampled conversion needs a trigger)
pub const fn set_tovs(&mut self, val: bool)
pub const fn set_tovs(&mut self, val: bool)
Triggered oversampling (0: all oversampled conversions are run after a single trigger, 1: each oversampled conversion needs a trigger)
pub const fn set_lftrig(&mut self, val: bool)
pub const fn set_lftrig(&mut self, val: bool)
Low frequency trigger mode enable
pub const fn set_ckmode(&mut self, val: Ckmode)
pub const fn set_ckmode(&mut self, val: Ckmode)
ADC clock mode